==> digikam_5.9.0.orig.tar.xz: digikam-5.9.0/core/libs/database/coredb/coredbthumbinfoprovider.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * http://www.digikam.org
 *
 * Date        : 2000-06-08
 * Description : Core database <-> thumbnail database interface
 *
 * Copyright (C) 2009      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
 * Copyright (C) 2009-2018 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef COREDATABASETHUMBNAILINFOPROVIDER_H
#define COREDATABASETHUMBNAILINFOPROVIDER_H

// Local includes

#include "digikam_export.h"
#include "thumbnailinfo.h"
#include "loadsavethread.h"

namespace Digikam
{

class DIGIKAM_DATABASE_EXPORT ThumbsDbInfoProvider : public ThumbnailInfoProvider
{
public:

    ThumbnailInfo thumbnailInfo(const ThumbnailIdentifier& identifier);
};

class DIGIKAM_DATABASE_EXPORT DatabaseLoadSaveFileInfoProvider : public LoadSaveFileInfoProvider
{
public:

    virtual int orientationHint(const QString& path);
};

}  // namespace Digikam

#endif /* COREDATABASETHUMBNAILINFOPROVIDER_H */

==> digikam-6.1.0.tar.xz: digikam-6.1.0/core/libs/database/coredb/coredbthumbinfoprovider.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2000-06-08
 * Description : Core database <-> thumbnail database interface
 *
 * Copyright (C) 2009      by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
 * Copyright (C) 2009-2019 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_CORE_DB_THUMB_INFO_PROVIDER_H
#define DIGIKAM_CORE_DB_THUMB_INFO_PROVIDER_H

// Local includes

#include "digikam_export.h"
#include "thumbnailinfo.h"
#include "loadsavethread.h"

namespace Digikam
{

class DIGIKAM_DATABASE_EXPORT ThumbsDbInfoProvider : public ThumbnailInfoProvider
{
public:

    ThumbnailInfo thumbnailInfo(const ThumbnailIdentifier& identifier);
};

class DIGIKAM_DATABASE_EXPORT DatabaseLoadSaveFileInfoProvider : public LoadSaveFileInfoProvider
{
public:

    virtual int orientationHint(const QString& path);
};

} // namespace Digikam

#endif // DIGIKAM_CORE_DB_THUMB_INFO_PROVIDER_H
